@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: caps.c,v 1.20 2003/01/23 20:28:49 nalin Exp $"
+#ident "$Id: caps.c,v 1.23 2004/11/17 00:23:44 nalin Exp $"
 #include "../config.h"
 #include <stdlib.h>
 #include <glib.h>
@@ -29,16 +29,16 @@
 #define PM  _VTE_CAP_PM
 #define APC _VTE_CAP_APC
 
-#define ENQ ""
-#define BEL ""
-#define BS  ""
-#define TAB "	"
-#define LF  "\n"
-#define VT  ""
-#define FF  ""
-#define CR  "\r"
-#define SO  ""
-#define SI  ""
+#define ENQ "\005"
+#define BEL "\007"
+#define BS  "\010"
+#define TAB "\011"
+#define LF  "\012"
+#define VT  "\013"
+#define FF  "\014"
+#define CR  "\015"
+#define SO  "\016"
+#define SI  "\017"
 
 /* This list combined from the Linux termcap(5) man page, and
  * termcap_&_terminfo by Strang, Mui, and O'Reilly. */
@@ -364,6 +364,8 @@ struct _vte_capability_quark _vte_terminal_capability_strings[] = {
  * version at Moy, Gildea, and Dickey. */
 struct _vte_capability_string _vte_xterm_capability_strings[] = {
 	{ENQ, "return-terminal-status", 0},
+	{VT,  "vertical-tab", 0},
+	{FF,  "form-feed", 0},
 
 	{ESC " F", "7-bit-controls", 0},
 	{ESC " G", "8-bit-controls", 0},
@@ -467,6 +469,7 @@ struct _vte_capability_string _vte_xterm_capability_strings[] = {
 	{CSI ">%dc", "send-secondary-device-attributes", 0},
 	{CSI "=c", "send-tertiary-device-attributes", 0},
 	{CSI "=%dc", "send-tertiary-device-attributes", 0},
+	{CSI "?%mc", "linux-console-cursor-attributes", 0},
 	{CSI "d", "line-position-absolute", 0},
 	{CSI "%dd", "line-position-absolute", 0},
 	{CSI ";f", "horizontal-and-vertical-position", 0},
@@ -476,22 +479,15 @@ struct _vte_capability_string _vte_xterm_capability_strings[] = {
 	{CSI "g", "tab-clear", 0},
 	{CSI "%dg", "tab-clear", 0},
 
-	{CSI "h", "set-mode", 0},
 	{CSI "%mh", "set-mode", 0},
-	{CSI "?h", "decset", 0},
 	{CSI "?%mh", "decset", 0},
 
-	{CSI "i", "media-copy", 0},
 	{CSI "%mi", "media-copy", 0},
-	{CSI "?i", "dec-media-copy", 0},
 	{CSI "?%mi", "dec-media-copy", 0},
 
-	{CSI "l", "reset-mode", 0},
 	{CSI "%ml", "reset-mode", 0},
-	{CSI "?l", "decreset", 0},
 	{CSI "?%ml", "decreset", 0},
 
-	{CSI "m", "character-attributes", 0},
 	{CSI "%mm", "character-attributes", 0},
 
 	{CSI "%dn", "device-status-report", 0},
@@ -501,9 +497,7 @@ struct _vte_capability_string _vte_xterm_capability_strings[] = {
 	{CSI "%d\"q", "select-character-protection", 0},
 	{CSI "r", "set-scrolling-region", 0},
 	{CSI "%d;%dr", "set-scrolling-region", 0},
-	{CSI "?r", "restore-mode", 0},
 	{CSI "?%mr", "restore-mode", 0},
-	{CSI "?s", "save-mode", 0},
 	{CSI "?%ms", "save-mode", 0},
 
 	{CSI "%mt", "window-manipulation", 0},
