@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001,2002 Red Hat, Inc.
+ * Copyright (C) 2001,2002,2003 Red Hat, Inc.
  *
  * This is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Library General Public License as published by
@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: interpret.c,v 1.18 2003/04/18 00:14:54 nalin Exp $"
+#ident "$Id: interpret.c,v 1.22 2005/03/14 14:43:47 kmaraas Exp $"
 #include "../config.h"
 #include <sys/types.h>
 #include <assert.h>
@@ -33,7 +33,7 @@
 #include "debug.h"
 #include "iso2022.h"
 #include "matcher.h"
-#include "termcap.h"
+#include "vtetc.h"
 
 int
 main(int argc, char **argv)
@@ -55,7 +55,7 @@ main(int argc, char **argv)
 	_vte_debug_parse_string(getenv("VTE_DEBUG_FLAGS"));
 
 	if (argc < 2) {
-		printf("usage: %s terminal [file]\n", argv[0]);
+		g_print("usage: %s terminal [file]\n", argv[0]);
 		return 1;
 	}
 
@@ -72,7 +72,6 @@ main(int argc, char **argv)
 
 	g_type_init();
 	terminal = argv[1];
-	matcher = _vte_matcher_new(terminal);
 	termcap = _vte_termcap_new(g_strdup_printf(DATADIR "/" PACKAGE
 						   "/termcap/%s", terminal));
 	if (termcap == NULL) {
@@ -81,29 +80,7 @@ main(int argc, char **argv)
 	buffer = _vte_buffer_new();
 	array = g_array_new(TRUE, TRUE, sizeof(gunichar));
 
-	for (i = 0;
-	     _vte_terminal_capability_strings[i].capability != NULL;
-	     i++) {
-		const char *capability;
-		char *tmp;
-		capability = _vte_terminal_capability_strings[i].capability;
-		if (_vte_terminal_capability_strings[i].key) {
-			continue;
-		}
-		tmp = _vte_termcap_find_string(termcap, terminal, capability);
-		if ((tmp != NULL) && (strlen(tmp) > 0)) {
-			_vte_matcher_add(matcher, tmp, strlen(tmp), capability,
-				       g_quark_from_static_string(capability));
-		}
-		g_free(tmp);
-	}
-	for (i = 0; _vte_xterm_capability_strings[i].value != NULL; i++) {
-		const char *code, *value;
-		code = _vte_xterm_capability_strings[i].code;
-		value = _vte_xterm_capability_strings[i].value;
-		_vte_matcher_add(matcher, code, strlen(code), value,
-				 g_quark_from_static_string(code));
-	}
+	matcher = _vte_matcher_new(terminal, termcap);
 
 	subst = _vte_iso2022_state_new(NULL, NULL, NULL);
 
@@ -139,41 +116,41 @@ main(int argc, char **argv)
 				c &= ~VTE_ISO2022_ENCODED_WIDTH_MASK;
 			}
 			if (c < 32) {
-				printf("`^%c'\n", c + 64);
+				g_print("`^%c'\n", c + 64);
 			} else
 			if (c < 127) {
-				printf("`%c'\n", c);
+				g_print("`%c'\n", c);
 			} else {
-				printf("`0x%x'\n", c);
+				g_print("`0x%x'\n", c);
 			}
 			i++;
 			continue;
 		}
 
 		l = j;
-		printf("%s(", g_quark_to_string(quark));
+		g_print("%s(", g_quark_to_string(quark));
 		for (j = 0; (values != NULL) && (j < values->n_values); j++) {
 			if (j > 0) {
-				printf(", ");
+				g_print(", ");
 			}
 			value = g_value_array_get_nth(values, j);
 			if (G_VALUE_HOLDS_LONG(value)) {
-				printf("%ld", g_value_get_long(value));
+				g_print("%ld", g_value_get_long(value));
 			}
 			if (G_VALUE_HOLDS_STRING(value)) {
-				printf("`%s'",
-				       g_value_get_string(value));
+				g_print("`%s'",
+				        g_value_get_string(value));
 			}
 			if (G_VALUE_HOLDS_POINTER(value)) {
-				printf("`%ls'",
-				       (wchar_t*)
-				       g_value_get_pointer(value));
+				g_print("`%ls'",
+				        (wchar_t*)
+				        g_value_get_pointer(value));
 			}
 		}
 		if (values != NULL) {
-			g_value_array_free(values);
+			_vte_matcher_free_params_array(values);
 		}
-		printf(")\n");
+		g_print(")\n");
 		i += l;
 	}
 
